@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef LAYOUTNAMES_H
-#define LAYOUTNAMES_H
+#pragma once
 
 #include <QMetaType>
 
@@ -22,5 +21,3 @@ Q_DECLARE_METATYPE(LayoutNames)
 
 QDBusArgument &operator<<(QDBusArgument &argument, const LayoutNames &layoutNames);
 const QDBusArgument &operator>>(const QDBusArgument &argument, LayoutNames &layoutNames);
-
-#endif // LAYOUTNAMES_H
