@@ -24,16 +24,10 @@ class TouchpadDisabler : public KDEDModule
 public:
     TouchpadDisabler(QObject *, const QVariantList &);
 
-Q_SIGNALS:
-    Q_SCRIPTABLE void enabledChanged(bool);
-    Q_SCRIPTABLE void workingTouchpadFoundChanged(bool);
-
 public Q_SLOTS:
     Q_SCRIPTABLE Q_NOREPLY void toggle();
     Q_SCRIPTABLE Q_NOREPLY void disable();
     Q_SCRIPTABLE Q_NOREPLY void enable();
-    Q_SCRIPTABLE bool isEnabled() const;
-    Q_SCRIPTABLE bool workingTouchpadFound() const;
 
 private Q_SLOTS:
     void updateCurrentState();
@@ -44,14 +38,13 @@ private Q_SLOTS:
 
 private:
     void lateInit();
-    void updateWorkingTouchpadFound();
     void showOsd();
 
     TouchpadBackend *m_backend;
     QDBusServiceWatcher m_dependencies;
 
-    bool m_userRequestedState, m_touchpadEnabled;
-    bool m_workingTouchpadFound;
+    bool m_touchpadSuspended = false;
+    bool m_userRequestedSuspend = false;
 
     bool m_preparingForSleep = false;
 };
